@@ -8,7 +8,7 @@ class TABLE_NAMES():
 
 
 class MAGNET_TABLE_TYPES():
-    VCOR = 'VCOR'
-    HCOR = 'HCOR'
+    VCOR = 'PeCorV'
+    HCOR = 'PeCorH'
     QUADRUPOLE = 'QUADRUPOLE'
     SIXTRUPOLE = 'SIXTRUPOLE'
