@@ -1,8 +1,4 @@
 import os
-
-from .PetraSimulationAdapter import PetraSimulationAdapter
-from .PetraMachineAdapter import PetraMachineAdapter
-
 import argparse
 
 
@@ -11,26 +7,30 @@ def set_service_by_env_values():
     mode = os.environ.get('SERVICE_MODE')
     if name == None:
         raise Exception('Environment SERVICE_NAME is not set.')
-    adapter = None
+    read = None
     if mode == 'sim':
-        adapter = PetraSimulationAdapter()
+        from ..adapter.TineSimAdapter import TineSimReader
+        read = TineSimReader.create_for_petra()
     elif mode == 'prod':
-        adapter = PetraMachineAdapter()
+        from ..adapter.TineAdapter import TineReader
+        read = TineReader()
     else:
         raise Exception('Environment SERVICE_MODE have to set to "sim" or "prod".')
-    return name, adapter, mode
+    return name, read, mode
 
 
 def set_adapter_by_arg_parser():
     parser = argparse.ArgumentParser(description='Short sample app')
     parser.add_argument('--mode', help="mode can be 'prod' or 'sim'")
     options = parser.parse_args()
-    adapter = None
+    read = None
 
     if options.mode == 'sim':
-        adapter = PetraSimulationAdapter()
+        from ..adapter.TineSimAdapter import TineSimReader
+        read = TineSimReader.create_for_petra()
     elif options.mode == 'prod':
-        adapter = PetraMachineAdapter()
+        from ..adapter.TineAdapter import TineReader
+        read = TineReader()
     else:
         raise Exception("Argument --mode isn't set. Possible values are 'prod' for production or 'sim' for simulation")
-    return adapter, options.mode
+    return read, options.mode
